#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from pyams_portal.interfaces import IPortalContext, IPortalPage, IPortalTemplate
from pyams_utils.container import find_objects_providing
from pyams_utils.interfaces.intids import IUniqueID
from pyams_utils.registry import get_local_registry, get_utilities_for, set_local_registry


def evolve(site):
    """Evolve 2: rename resource annotations"""
    old_registry = get_local_registry()
    try:
        registry = site.getSiteManager()
        set_local_registry(registry)
        # Update templates registry
        renames = {}
        for name, template in get_utilities_for(IPortalTemplate):
            new_name = IUniqueID(template).oid
            renames[name] = new_name
            registry.unregisterUtility(template, IPortalTemplate, name=name)
            registry.registerUtility(template, IPortalTemplate, name=new_name)
        # Update templates references
        for context in find_objects_providing(site, IPortalContext):
            page = IPortalPage(context)
            page._shared_template = renames.get(page._shared_template)
            print("Upgrading template name for « {} »".format(context))
    finally:
        set_local_registry(old_registry)
